==> zen4R_0.6-1.tar.gz: zen4R/README.md <==
[![Build Status](https://github.com/eblondel/zen4R/actions/workflows/r-cmd-check.yml/badge.svg?branch=master)](https://github.com/eblondel/zen4R/actions/workflows/r-cmd-check.yml)
[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/zen4R)](https://cran.r-project.org/package=zen4R)
[![Github_Status_Badge](https://img.shields.io/badge/Github-0.6--1-blue.svg)](https://github.com/eblondel/zen4R)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2547036.svg)](https://doi.org/10.5281/zenodo.2547036)

**zen4R – R Interface to Zenodo REST API**

``zen4R`` provides an interface to the [Zenodo e-infrastructure](https://zenodo.org) API.

Please check the [online documentation](https://github.com/eblondel/zen4R/wiki) for more details!

## Sponsors

Many thanks to the following organizations that have provided fundings for strenghtening the ``geoflow`` package:

<div style="float:left;">
  <a href="https://www.fao.org/home/en/"><img height=200 width=200 src="https://www.fao.org/fileadmin/templates/family-farming-decade/images/FAO-IFAD-Logos/FAO-Logo-EN.svg">
<a href="https://en.ird.fr/"><img src="https://en.ird.fr/sites/ird_fr/files/2019-08/logo_IRD_2016_BLOC_UK_COUL.png" height=200 width=200/></a>
</div>

<br><br><br><br><br><br><br><br><br><br><br><br><br>

The following projects have contributed to strenghten ``zen4R``:

<a href="https://blue-cloud.org/"><img height=100 width=300 src="https://www.blue-cloud.org/sites/all/themes/arcadia/logo.png"/></a>

_Blue-Cloud has received funding from the European Union's Horizon programme call BG-07-2019-2020, topic: [A] 2019 - Blue Cloud services, Grant Agreement No.862409._


For zen4R sponsoring/funding new developments, enhancements, support requests, please contact me by [e-mail](mailto:eblondel.pro@gmail.com)

## Citation

We thank in advance people that use ``zen4R`` for citing it in their work / publication(s). For this, please use the citation provided at this link [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2547036.svg)](https://doi.org/10.5281/zenodo.2547036)

==> zen4R_0.7.tar.gz: zen4R/README.md <==
[![Build Status](https://github.com/eblondel/zen4R/actions/workflows/r-cmd-check.yml/badge.svg?branch=master)](https://github.com/eblondel/zen4R/actions/workflows/r-cmd-check.yml)
[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/zen4R)](https://cran.r-project.org/package=zen4R)
[![Github_Status_Badge](https://img.shields.io/badge/Github-0.7-blue.svg)](https://github.com/eblondel/zen4R)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2547036.svg)](https://doi.org/10.5281/zenodo.2547036)

**zen4R – R Interface to Zenodo REST API**

``zen4R`` provides an interface to the [Zenodo e-infrastructure](https://zenodo.org) API.

Please check the [online documentation](https://github.com/eblondel/zen4R/wiki) for more details!

## Sponsors

Many thanks to the following organizations that have provided fundings for strenghtening the ``geoflow`` package:

<div style="float:left;">
  <a href="https://www.fao.org/home/en/"><img height=200 width=200 src="https://www.fao.org/fileadmin/templates/family-farming-decade/images/FAO-IFAD-Logos/FAO-Logo-EN.svg">
<a href="https://en.ird.fr/"><img src="https://en.ird.fr/sites/ird_fr/files/2019-08/logo_IRD_2016_BLOC_UK_COUL.png" height=200 width=200/></a>
</div>

<br><br><br><br><br><br><br><br><br><br><br><br><br>

The following projects have contributed to strenghten ``zen4R``:

<a href="https://blue-cloud.org/"><img height=100 width=300 src="https://www.blue-cloud.org/sites/all/themes/arcadia/logo.png"/></a>

_Blue-Cloud has received funding from the European Union's Horizon programme call BG-07-2019-2020, topic: [A] 2019 - Blue Cloud services, Grant Agreement No.862409._


For zen4R sponsoring/funding new developments, enhancements, support requests, please contact me by [e-mail](mailto:eblondel.pro@gmail.com)

## Citation

We thank in advance people that use ``zen4R`` for citing it in their work / publication(s). For this, please use the citation provided at this link [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2547036.svg)](https://doi.org/10.5281/zenodo.2547036)
